# CustardPy (PyPI)

- Python 3.7+

## Installation

The core component of CustardPy can be installed using pip3:
The following are required before installing CustardPy:

    pip3 install custardpy

## ChangeLog

- 0.7.8 (2026.3.16)
   - Bug fix in `plotInsulationScore` where the matplotlib.pyplot was not imported.

- 0.7.6 (2025-06-27)
   - Lint check with Ruff.

- 0.7.2 (2024-03-05)
   - Fixed the error messages in `plotHiCfeature_module.py`

- 0.7.1 (2024-03-03)
   - Added the function `plot_SamplePair_triu`

- 0.7.0 (2024-03-03)
   - Added this ChangeLog
   - Create `plotHiCfeature_module.py`
   - Add `__version__` to __init__.py
